@@ -43,7 +43,7 @@ class SqlAlchemyPool(BaseConnectionPool):
         pool_recycle = params.pop("pool_recycle", 3600)
         max_overflow = params.pop("max_overflow", 0)
         pool_timeout = params.pop("pool_timeout", 10)
-        pool_pre_ping = params.pop("pool_pre_ping", True)
+        pool_pre_ping = params.pop("pool_pre_ping", False)
         engine = sqlalchemy.create_engine(url, echo=echo,
                                           pool_size=self.conn_info.min_size,
                                           pool_recycle=pool_recycle,
