@@ -77,6 +77,8 @@ class StatusCode:
     FILE_STORAGE_EXCEPTION = ("A0335", "文件存储异常")
     DATABASE_CONNECT_EXCEPTION = ("A0336", "数据库连接异常")
     UNABLE_OBTAIN_PHONE = ("A0340", "无法获取到手机号")
+    UNAUTHORIZED_USER = ("A0341", "没有找到授权的用户")
+    DATA_ERROR = ("A0342", "数据有误")
 
     @staticmethod
     def MONITOR_EXCEPTION(message):
@@ -236,6 +238,15 @@ class StatusCode:
         """
         return "B0501", "{}已存在,确保唯一性，不可重复".format(message)
 
+    @staticmethod
+    def RESOURCE_NOT_EXIST(message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "B0502", "{}".format(message)
+
     # C00开头的状态码
     RPC_INVOKE_ERROR = ("C0001", "调用第三方服务出错")
     SERVER_ERROR = ("C0002", "服务器内部错误")
@@ -250,6 +261,14 @@ class StatusCode:
     # C04开头的状态码
 
     # C05开头的状态码
+    @staticmethod
+    def AT_LEAST_ONE_NOT_EMPYT(message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "C0502", "{}至少存在一个不为空".format(message)
 
     @staticmethod
     def COMMON_CODE_MESSAGE(status_code, message):
